@@ -177,8 +177,11 @@ class Agent(Insight, Channel, Catalog, Dataset):
         self._get_info_dataset_by_slug(slug)
         return self
 
-    def query(self, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id="", limit=50, offset=0):
 
+    def query(self, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id="", limit=50, offset=0, pivot=[]):
+        """
+        Pivot columns MUST be contained in field list
+        """
         if(fields==[]):
             print("SELECT FIELDS")
             return
@@ -218,7 +221,8 @@ class Agent(Insight, Channel, Catalog, Dataset):
             "sortedBy": sorted_by,
             "filters": filters,
             "limit": limit,
-            "offset": offset
+            "offset": offset,
+            "pivot": pivot
         }
 
         print(body)
@@ -934,7 +938,6 @@ class Askdata(SignUp):
             response.raise_for_status()
             dataset = response.json()
             dataset_id = dataset["id"]
-
         else:
             s = requests.Session()
             s.keep_alive = False
@@ -1185,7 +1188,7 @@ class Askdata(SignUp):
             })
         return pd.DataFrame(data=columns)
 
-    def query(self, workspace='', dataset='', fields:list=[], filters=None, sorted_by=None, limit=50, offset=0):
+    def query(self, workspace='', dataset='', fields:list=[], filters=None, sorted_by=None, limit=50, offset=0, pivot=[]):
 
         if (workspace == ''):
             if ('/' in dataset):
@@ -1194,7 +1197,7 @@ class Askdata(SignUp):
 
 
         agent = self.agent(slug=workspace)
-        return agent.query(dataset_slug, fields, filters, sorted_by, limit=limit, offset=offset)
+        return agent.query(dataset_slug, fields, filters, sorted_by, limit=limit, offset=offset, pivot=pivot)
 
 
     def get(self, query, workspace='', dataset='', lang="en", fields:list=[], filters=None, sorted_by=None, get_raw_data=False):
